==> astro-1.0.15.tgz: package/src/utils/writeVirtualServicePluginExtensionFiles.ts <==
import { rm, writeFile } from 'node:fs/promises';
import { join, resolve } from 'node:path';
import { globby } from 'globby';
import { outdent } from 'outdent';
import type { Model } from '../types.js';
import { isValidServicePluginComponent } from './isValidServicePluginComponent.js';

export async function writeVirtualServicePluginExtensionFiles(
  model: Model,
  codegenDir: string
) {
  const servicePluginComponents = model.components.filter(
    isValidServicePluginComponent
  );

  const existingFiles = await globby(`*.ts`, {
    cwd: codegenDir,
    onlyFiles: true,
  });

  for (const filename of existingFiles) {
    const hasMatchingSourceFile = servicePluginComponents.some(
      (component) => `${component.manifest.compId}.ts` === filename
    );

    if (hasMatchingSourceFile) {
      continue;
    }

    await rm(join(codegenDir, filename));
  }

  for (const component of servicePluginComponents) {
    const originalEntrypoint = resolve(component.directory, 'plugin.ts');
    const virtualEntrypoint = join(
      codegenDir,
      `${component.manifest.compId}.ts`
    );

    await writeFile(
      virtualEntrypoint,
      outdent`
        import type { APIRoute } from 'astro';
        import { AppStrategy, createClient } from '@wix/sdk';
        import { WIX_CLIENT_ID } from 'astro:env/client';
        import { WIX_CLIENT_PUBLIC_KEY, WIX_CLIENT_SECRET } from 'astro:env/server';

        const client = createClient({
          auth: AppStrategy({
            appId: WIX_CLIENT_ID,
            appSecret: WIX_CLIENT_SECRET,
            publicKey: WIX_CLIENT_PUBLIC_KEY,
          }),
        });

        const olderClient = globalThis.__wix_context__.client;

        client.enableContext('global');

        await import('${originalEntrypoint}');

        if (olderClient) {
          olderClient.enableContext('global');
        }

        export const ALL: APIRoute = async (context) => {
          return await client.servicePlugins.processRequest(context.request);
        };
      `
    );
  }
}

==> astro-1.0.17.tgz: package/src/utils/writeVirtualServicePluginExtensionFiles.ts <==
import { rm, writeFile } from 'node:fs/promises';
import { join, resolve } from 'node:path';
import { globby } from 'globby';
import { outdent } from 'outdent';
import type { Model } from '../types.js';
import { toRelativePath } from './fs-utils.js';
import { isValidServicePluginComponent } from './isValidServicePluginComponent.js';

export async function writeVirtualServicePluginExtensionFiles(
  model: Model,
  codegenDir: string
) {
  const servicePluginComponents = model.components.filter(
    isValidServicePluginComponent
  );

  const existingFiles = await globby(`*.ts`, {
    cwd: codegenDir,
    onlyFiles: true,
  });

  for (const filename of existingFiles) {
    const hasMatchingSourceFile = servicePluginComponents.some(
      (component) => `${component.manifest.compId}.ts` === filename
    );

    if (hasMatchingSourceFile) {
      continue;
    }

    await rm(join(codegenDir, filename));
  }

  for (const component of servicePluginComponents) {
    const originalEntrypoint = resolve(component.directory, 'plugin.ts');
    const virtualEntrypoint = join(
      codegenDir,
      `${component.manifest.compId}.ts`
    );

    await writeFile(
      virtualEntrypoint,
      outdent`
        import type { APIRoute } from 'astro';
        import { AppStrategy, createClient } from '@wix/sdk';
        import { WIX_CLIENT_ID } from 'astro:env/client';
        import { WIX_CLIENT_PUBLIC_KEY, WIX_CLIENT_SECRET } from 'astro:env/server';

        const client = createClient({
          auth: AppStrategy({
            appId: WIX_CLIENT_ID,
            appSecret: WIX_CLIENT_SECRET,
            publicKey: WIX_CLIENT_PUBLIC_KEY,
          }),
        });

        const olderClient = globalThis.__wix_context__.client;

        client.enableContext('global');

        await import('${toRelativePath(virtualEntrypoint, originalEntrypoint)}');

        if (olderClient) {
          olderClient.enableContext('global');
        }

        export const ALL: APIRoute = async (context) => {
          return await client.servicePlugins.processRequest(context.request);
        };
      `
    );
  }
}
